## CIRI-long: circular RNA identifier using long-read sequencing data

[![Build Status](https://staging.travis-ci.com/bioinfo-biols/CIRI-long.svg?branch=master)](https://staging.travis-ci.com/bioinfo-biols/CIRI-long)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/bioinfo-biols/CIRI-long)
[![The MIT License](https://img.shields.io/badge/license-MIT-orange.svg)](https://github.com/bioinfo-biols/CIRI-long/blob/master/LICENSE)
![GitHub All Releases](https://img.shields.io/github/downloads/bioinfo-biols/CIRI-long/total)
[![Documentation Status](https://readthedocs.org/projects/ciri-cookbook/badge/?version=latest)](https://ciri-cookbook.readthedocs.io/en/latest/?badge=latest)

Circular RNA Identification for Long-Reads Nanopore Sequencing Data

### Documentation

Documentation is available online at [https://ciri-cookbook.readthedocs.io/en/latest](https://ciri-cookbook.readthedocs.io/en/latest/CIRI-long_0_home.html#)

### Author

Authors: Jinyang Zhang(zhangjinyang@biols.ac.cn), Fangqing Zhao(zhfq@biols.ac.cn)

Maintainer: Jinyang Zhang

### Release Notes

- version 1.0.2: Add fast mode for ccs detection and option for user-provide circRNA annotation
- version 1.0.1: Fixed bug
- version 1.0: First released version

### License

The code is released under the MIT License. See the `LICENSE` file for more detail

### Citing CIRI-long

Zhang, J., Hou, L., Zuo, Z., Ji, P., Zhang, X., Xue, Y., & Zhao, F. (2021). Comprehensive profiling of circular RNAs with nanopore sequencing and CIRI-long. Nature Biotechnology. https://doi.org/10.1038/s41587-021-00842-6
